==> alfred-ui-native-components-0.0.72.tgz: package/ui/atoms/switch/switch/styles.ts <==
import { StyleSheet } from 'react-native';
import { sizeTypes } from '.';
import { getThemeColorByDefaultColor } from '../../../../utils';

export type SizeOption = 'SMALL' | 'MEDIUM' | 'LARGE';

const sizeManager = {
  [sizeTypes.SMALL]: {
    scaleX: 0.6,
    scaleY: 0.6,
  },
  [sizeTypes.MEDIUM]: {
    scaleX: 0.8,
    scaleY: 0.8,
  },
  [sizeTypes.LARGE]: {
    scaleX: 1,
    scaleY: 1,
  },
};

export const defaultTrackColor = {
  false: getThemeColorByDefaultColor('background', 'dark'),
  true: getThemeColorByDefaultColor('primary', 'default'),
};

export const defaultBorderColor = {
  false: getThemeColorByDefaultColor('text', 'extraLight'),
  true: getThemeColorByDefaultColor('primary', 'default'),
};

export const defaultValueBorderColor = {
  false: getThemeColorByDefaultColor('text', 'extraLight'),
  true: getThemeColorByDefaultColor('primary', 'default'),
};

const defaultThumbColor = getThemeColorByDefaultColor(
  'background',
  'extraLight',
);

interface StylesOptions {
  disabled?: boolean;
  size?: SizeOption;
  value: boolean;
}

export const styles = ({ value, disabled, size = 'MEDIUM' }: StylesOptions) => {
  const borderValueColor = value
    ? defaultBorderColor.false
    : defaultBorderColor.true;
  
  const borderColor = disabled
    ? defaultBorderColor.false
    : borderValueColor;

  return StyleSheet.create({
    innerCircleStyle: {
      backgroundColor: defaultThumbColor,
      borderColor: borderColor,
      borderWidth: 2,
      alignItems: 'center',
      justifyContent: 'center',
      transform: [{ scaleX: 0.8 }, { scaleY: 0.8 }],
    },
    containerStyle: {
      transform: [
        { scaleX: sizeManager[size].scaleX },
        { scaleY: sizeManager[size].scaleY },
      ],
    },
  });
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/atoms/switch/switch/styles.ts <==
import { StyleSheet } from 'react-native';
import { sizeTypes } from '.';
import { getThemeColorByDefaultColor } from '../../../../utils';

export type SizeOption = 'SMALL' | 'MEDIUM' | 'LARGE';

const sizeManager = {
  [sizeTypes.SMALL]: {
    scaleX: 0.6,
    scaleY: 0.6,
  },
  [sizeTypes.MEDIUM]: {
    scaleX: 0.8,
    scaleY: 0.8,
  },
  [sizeTypes.LARGE]: {
    scaleX: 1,
    scaleY: 1,
  },
};

export const defaultTrackColor = () => ({
  false: getThemeColorByDefaultColor('background', 'dark'),
  true: getThemeColorByDefaultColor('primary', 'default'),
});

export const defaultBorderColor = () => ({
  false: getThemeColorByDefaultColor('text', 'extraLight'),
  true: getThemeColorByDefaultColor('primary', 'default'),
});

export const defaultValueBorderColor = () => ({
  false: getThemeColorByDefaultColor('text', 'extraLight'),
  true: getThemeColorByDefaultColor('primary', 'default'),
});

const defaultThumbColor = getThemeColorByDefaultColor(
  'background',
  'extraLight',
);

interface StylesOptions {
  disabled?: boolean;
  size?: SizeOption;
  value: boolean;
}

export const styles = ({ value, disabled, size = 'MEDIUM' }: StylesOptions) => {
  const borderValueColor = value
    ? defaultBorderColor().false
    : defaultBorderColor().true;

  const borderColor = disabled
    ? defaultBorderColor().false
    : borderValueColor;

  return StyleSheet.create({
    innerCircleStyle: {
      backgroundColor: defaultThumbColor,
      borderColor: borderColor,
      borderWidth: 2,
      alignItems: 'center',
      justifyContent: 'center',
      transform: [{ scaleX: 0.8 }, { scaleY: 0.8 }],
    },
    containerStyle: {
      transform: [
        { scaleX: sizeManager[size].scaleX },
        { scaleY: sizeManager[size].scaleY },
      ],
    },
  });
};
